library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity DigitalWatch is
    port(   reset, clk                 : in    std_logic;
            sw0, sw1, sw2, sw3         : in    std_logic;
            hourFND, minFND, secFND    : out   std_logic_vector(6 downto 0);
            hourFNDSel2, hourFNDSel1   : out   std_logic;
            minFNDSel2, minFNDSel1     : out   std_logic;
            secFNDSel2, secFNDSel1     : out   std_logic;
            mode_out                   : out   std_logic_vector(1 downto 0);
            set_pos_out                : out   std_logic_vector(2 downto 0);
            alarm_out                  : out   std_logic_vector(2 downto 0);
            alarm_on                   : out   std_logic_vector(2 downto 0));
end DigitalWatch;
---------------------------------------------------------------------------------------------------------------
architecture Behavioral of DigitalWatch is
 component MasterSelect
      port(  reset							  : in	std_logic;
             clk                              : in    std_logic;
             sw0, sw1                         : in    std_logic;
             clk1hz_out, clk2hz_out           : out    std_logic;
             mode_out                         : out    std_logic_vector(1 downto 0);
             set_pos_out                      : out    std_logic_vector(2 downto 0);
             clk100hz_out                     : out std_logic);
   end component;
---------------------------------------------------------------------------------------------------------------
   component DigitalClock
   PORT(  clk					  : in 	std_logic;
          reset                   : in     std_logic;
          clk1hz, clk2hz          : in     std_logic;
          blink                   : in     std_logic;
          mode                    : in    std_logic_vector(1 downto 0);
          set_pos                 : in    std_logic_vector(2 downto 0);
          sw2                     : in    std_logic;
         
          sec_out                 : out    std_logic_vector(5 downto 0);
          min_out                 : out    std_logic_vector(5 downto 0);
          hour_out                : out    std_logic_vector(4 downto 0));
   end component;
---------------------------------------------------------------------------------------------------------------
   component FNDDisplay
   PORT( reset							: in	std_logic;
         clk, clk2hz, clk100hz          : in    std_logic;
         sw2                            : in    std_logic;
         mode                           : in    std_logic_vector(1 downto 0);
         set_pos                        : in    std_logic_vector(2 downto 0);
         dc_sec, dc_min                 : in    std_logic_vector(5 downto 0);
         dc_hour                        : in    std_logic_vector(4 downto 0);
         tl_mmsec                       : in     std_logic_vector(6 downto 0);
         tl_sec, tl_min                 : in    std_logic_vector(5 downto 0);
         al_sec, al_min                 : in    std_logic_vector(5 downto 0);
         al_hour                        : in    std_logic_vector(4 downto 0);
  
         hourFND, minFND, secFND        : out    std_logic_vector(6 downto 0);
         hourFNDSel2, hourFNDSel1       : out    std_logic;    
         minFNDSel2, minFNDSel1         : out    std_logic;    
         secFNDSel2, secFNDSel1         : out    std_logic;
         blink_out                      : out std_logic);
   end component;
---------------------------------------------------------------------------------------------------------------
   component AlarmLogic
   PORT( reset				   : in	   std_logic;
         clk                     : in    std_logic;
         clk2hz                  : in    std_logic;
         clk100hz                : in    std_logic;
         mode                    : in    std_logic_vector(1 downto 0);
         blink                   : in    std_logic;
         set_pos                 : in    std_logic_vector(2 downto 0);
         
         clk_min                 : in    std_logic_vector(5 downto 0);
         clk_hour                : in    std_logic_vector(4 downto 0);
         
         sw2, sw3                : in    std_logic;
         
         sec_out                 : out    std_logic_vector(5 downto 0);
         min_out                 : out    std_logic_vector(5 downto 0);
         hour_out                : out    std_logic_vector(4 downto 0);
         alarm_out               : out    std_logic_vector(2 downto 0);
         alarm_on                : out    std_logic_vector(2 downto 0));
   end component;   
---------------------------------------------------------------------------------------------------------------   
   component TimerLogic
   PORT( reset				   : in	   std_logic;
         mode                    : in    std_logic_vector(1 downto 0);
         clk100hz                : in    std_logic;
         sw1, sw2                : in    std_logic;
         
         mmsec_out               : out   std_logic_vector(6 downto 0);
         sec_out                 : out   std_logic_vector(5 downto 0);
         min_out                 : out   std_logic_vector(5 downto 0));
   end component;   
---------------------------------------------------------------------------------------------------------------   
       signal clk1hz, clk2hz, clk100hz           :  std_logic;
       signal mode                               :  std_logic_vector(1 downto 0);
       signal set_pos                            :  std_logic_vector(2 downto 0);
       signal blink                              :  std_logic;     
       signal dc_sec, tl_sec, al_sec             : std_logic_vector(5 downto 0);
       signal dc_min, tl_min, al_min             : std_logic_vector(5 downto 0);
       signal dc_hour, al_hour                   : std_logic_vector(4 downto 0);        
       signal tl_mmsec                           : std_logic_vector(6 downto 0);  
        
begin
    MS0 : MasterSelect port map(reset => reset, clk => clk, sw0 => sw0, sw1 => sw1, clk1hz_out => clk1hz, 
            clk2hz_out => clk2hz, mode_out => mode, set_pos_out => set_pos, clk100hz_out => clk100hz);
    
    DC0: DigitalClock port map(clk => clk, reset => reset, clk1hz => clk1hz, clk2hz => clk2hz, blink => blink, 
            mode => mode, set_pos => set_pos, sw2 => sw2,   sec_out => dc_sec , min_out => dc_min, hour_out => dc_hour);
    
    FNDD0 : FNDDisplay port map(reset => reset, clk => clk, clk2hz => clk2hz, clk100hz => clk100hz, sw2 => sw2, mode => mode, 
            set_pos => set_pos,   dc_sec => dc_sec, dc_min => dc_min, dc_hour => dc_hour, tl_mmsec => tl_mmsec, tl_sec => tl_sec, 
            tl_min => tl_min, al_sec => al_sec, al_min => al_min, al_hour => al_hour, hourFND => hourFND, minFND => minFND, 
            secFND => secFND, hourFNDSel2 => hourFNDSel2, hourFNDSel1 => hourFNDSel1, minFNDSel2 => minFNDSel2, minFNDSel1 => minFNDSel1, 
            secFNDSel2 => secFNDSel2, secFNDSel1 => secFNDSel1, blink_out => blink);
            
    Ala0 : AlarmLogic port map(reset => reset, clk => clk, clk2hz => clk2hz, clk100hz => clk100hz, mode => mode, blink => blink, 
            set_pos => set_pos, clk_min => dc_min, clk_hour => dc_hour, sw2 => sw2, sw3 => sw3,sec_out => al_sec, 
            min_out => al_min , hour_out => al_hour, alarm_out => alarm_out, alarm_on => alarm_on);
            
    Tim0 : TimerLogic port map(reset => reset, mode => mode, clk100hz => clk100hz, sw1 => sw1, sw2 => sw2, 
            mmsec_out => tl_mmsec, sec_out => tl_sec, min_out => tl_min);
 
    mode_out <= mode;
    set_pos_out <= set_pos;
 
end Behavioral;