library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
 
entity DigitalWatch is
    port(   reset, clk :                in std_logic;
            sw0, sw1, sw2 :             in std_logic;
            hourFND, minFND, secFND :   out std_logic_vector(6 downto 0);
            hourFNDSel2, hourFNDSel1 :  out std_logic;
            minFNDSel2, minFNDSel1 :    out std_logic;
            secFNDSel2, secFNDSel1 :    out std_logic;
            mode_out :                  out std_logic_vector(1 downto 0);
            set_pos_out :               out std_logic_vector(2 downto 0));
end DigitalWatch;
 
architecture Behavioral of DigitalWatch is
    component MasterSelect
	   port(reset :                      in	std_logic;
            clk :                        in std_logic;
            sw0, sw1 :                   in std_logic;
            clk1hz_out :                 out std_logic;
            clk100hz_out :               out std_logic;
            mode_out :                   out std_logic_vector(1 downto 0);
            set_pos_out :                out std_logic_vector(2 downto 0));
    end component;

    component DigitalClock
	PORT(	clk	:                        in std_logic;
            reset :                      in std_logic;
            clk1hz :                     in std_logic;
            mode :                       in std_logic_vector(1 downto 0);
            set_pos :                    in std_logic_vector(2 downto 0);
            sw2 :                        in std_logic;
            sec_out :                    out std_logic_vector(5 downto 0);
            min_out :                    out std_logic_vector(5 downto 0);
            hour_out :                   out std_logic_vector(4 downto 0));
    end component;

    component FNDDisplay
	PORT(	clk, clk100hz :              in	std_logic;
            sec, min :                   in std_logic_vector(5 downto 0);
            hour :                       in std_logic_vector(4 downto 0);
            hourFND, minFND, secFND :    out std_logic_vector(6 downto 0);
            hourFNDSel2, hourFNDSel1 :   out std_logic;    
            minFNDSel2, minFNDSel1 :     out std_logic;    
            secFNDSel2, secFNDSel1 :     out std_logic);
    end component;
    
	signal clk1hz, clk100hz :            std_logic;
	signal mode :                        std_logic_vector(1 downto 0);
    signal set_pos :                     std_logic_vector(2 downto 0);
    signal sec :                         std_logic_vector(5 downto 0);
    signal min :                         std_logic_vector(5 downto 0);
    signal hour :                        std_logic_vector(4 downto 0);
 
begin
    MS0 : MasterSelect port map(reset => reset, clk => clk, sw0 => sw0, sw1 => sw1, clk1hz_out => clk1hz, clk100hz_out => clk100hz, mode_out => mode, set_pos_out => set_pos);
    DC0: DigitalClock port map(clk => clk, reset => reset, clk1hz => clk1hz, mode => mode, set_pos => set_pos, sw2 => sw2, sec_out => sec , min_out => min, hour_out => hour);
    FNDD0 : FNDDisplay port map(clk => clk, clk100hz => clk100hz, sec => sec, min => min, hour => hour, hourFND => hourFND, minFND => minFND, secFND => secFND, 
            hourFNDSel2 => hourFNDSel2, hourFNDSel1 => hourFNDSel1, minFNDSel2 => minFNDSel2, minFNDSel1 => minFNDSel1, secFNDSel2 => secFNDSel2, secFNDSel1 => secFNDSel1);

    mode_out <= mode;
    set_pos_out <= set_pos; 
end Behavioral;