
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity DigitalWatch is
    port(   reset, clk                          : in std_logic;
            sw0, sw1, sw2                       : in std_logic;
            
            hourFND, minFND, secFND             : out std_logic_vector(6 downto 0);
            hourFNDSel2, hourFNDSel1            : out std_logic;
            minFNDSel2, minFNDSel1              : out std_logic;
            secFNDSel2, secFNDSel1              : out std_logic;
            mode_out                            : out std_logic_vector(1 downto 0);
            set_pos_out                         : out std_logic_vector(2 downto 0));
end DigitalWatch;

architecture Behavioral of DigitalWatch is
    component MasterSelect
   port(reset								: in	std_logic;
         clk                                : in    std_logic;
         sw0, sw1                           : in    std_logic;
         
         clk1hz_out                         : out    std_logic;
         mode_out                           : out    std_logic_vector(1 downto 0);
         set_pos_out                        : out    std_logic_vector(2 downto 0);
         clk100hz_out                       : out    std_logic);
end component;

component DigitalClock
PORT(       clk					    :in     std_logic;
			reset					: in	std_logic;
			clk1hz				    : in	std_logic;
			mode					: in	std_logic_vector(1 downto 0);
			set_pos	     			: in	std_logic_vector(2 downto 0);
			sw2				      	: in	std_logic;
		
			sec_out			       	: out	std_logic_vector(5 downto 0);
			min_out				    : out	std_logic_vector(5 downto 0);
			hour_out				: out	std_logic_vector(4 downto 0));
end component;

component FNDDisplay
PORT(       clk, clk100hz			     : in	std_logic;
			mode						 : in	std_logic_vector(1 downto 0);
			dc_sec, dc_min			     : in	std_logic_vector(5 downto 0);
			dc_hour				         : in	std_logic_vector(4 downto 0);
			tl_mmsec					 : in 	std_logic_vector(6 downto 0);
			tl_sec, tl_min			     : in	std_logic_vector(5 downto 0);
		
			hourFND, minFND, secFND		: out	std_logic_vector(6 downto 0);
			hourFNDSel2, hourFNDSel1	: out	std_logic;	
			minFNDSel2, minFNDSel1		: out	std_logic;	
			secFNDSel2, secFNDSel1		: out	std_logic);
end component;

component TimerLogic
PORT(       reset				     : in	std_logic;
			mode					 : in	std_logic_vector(1 downto 0);
			clk100hz				 : in	std_logic;
			sw1, sw2				 : in	std_logic;
		
			mmsec_out			     : out	std_logic_vector(6 downto 0);
			sec_out				     : out	std_logic_vector(5 downto 0);
			min_out				     : out	std_logic_vector(5 downto 0));
end component;

signal clk1hz, clk100hz :            std_logic;
signal mode :                        std_logic_vector(1 downto 0);
signal set_pos :                     std_logic_vector(2 downto 0);
signal tl_mmsec :                    std_logic_vector(6 downto 0);
signal dc_sec, tl_sec :              std_logic_vector(5 downto 0);
signal dc_min, tl_min :              std_logic_vector(5 downto 0);
signal dc_hour :                     std_logic_vector(4 downto 0);


begin
   MS0 : MasterSelect port map(reset => reset, clk => clk, sw0 => sw0, sw1 => sw1, clk1hz_out => clk1hz, mode_out => mode, set_pos_out => set_pos, clk100hz_out => clk100hz);
   DC0: DigitalClock port map(clk => clk, reset => reset, clk1hz => clk1hz, mode => mode, set_pos => set_pos, sw2 => sw2, sec_out => dc_sec ,min_out => dc_min ,hour_out => dc_hour );
   FNDD0 : FNDDisplay port map(clk => clk, clk100hz => clk100hz, mode => mode, dc_sec => dc_sec, dc_min => dc_min, dc_hour => dc_hour, tl_mmsec => tl_mmsec, tl_sec => tl_sec, tl_min => tl_min, hourFND => hourFND, minFND => minFND, secFND => secFND, hourFNDSel2 => hourFNDSel2, hourFNDSel1 => hourFNDSel1, minFNDSel2 => minFNDSel2, minFNDSel1 => minFNDSel1, secFNDSel2 => secFNDSel2, secFNDSel1 => secFNDSel1);
   TL0 : TimerLogic port map(reset => reset, mode => mode, clk100hz => clk100hz, sw1 => sw1, sw2 => sw2, mmsec_out => tl_mmsec, sec_out => tl_sec, min_out => tl_min);
    
  mode_out <= mode;
  set_pos_out <= set_pos;    
    
end Behavioral;
